@@ -3,7 +3,7 @@ test_that("VizualiseQuartets()", {
   skip_if_not_installed("TreeTools", "1.7.0")
   vdiffr::expect_doppelganger("VQ-label", function() {
     VisualizeQuartets(BalancedTree(10), CollapseNode(PectinateTree(10), 19),
-                     style = 'label', precision = 1)
+                     style = "label", precision = 1)
   })
   vdiffr::expect_doppelganger("VQ-tworow", function() {
     # Keep original plotting parameters:
@@ -11,12 +11,12 @@ test_that("VizualiseQuartets()", {
     VisualizeQuartets(BalancedTree(10), CollapseNode(PectinateTree(10), 19),
                      setPar = FALSE)
     VisualizeQuartets(BalancedTree(10), CollapseNode(PectinateTree(10), 19),
-                     style = 'bar', legend = FALSE, setPar = FALSE,
-                     spectrum = c(rep('red', 100), 'green'))
+                     style = "bar", legend = FALSE, setPar = FALSE,
+                     spectrum = c(rep("red", 100), "green"))
     par(origPar)
   })
   vdiffr::expect_doppelganger("VQ-size", function() {
     VisualizeQuartets(BalancedTree(20), CollapseNode(PectinateTree(20), 29:33),
-                     style = 'size', scale = 2)
+                     style = "size", scale = 2)
   })
 })
\ No newline at end of file
